"""Key class binding"""
from __future__ import annotations
import maialib.maiacore.maiacore
import typing

__all__ = [
    "Barline",
    "Chord",
    "Clef",
    "ClefSign",
    "Duration",
    "HeapData",
    "Helper",
    "Interval",
    "Key",
    "Measure",
    "Note",
    "NoteData",
    "NoteDataHeap",
    "Part",
    "Score",
    "ScoreCollection"
]


class Barline():
    def __hash__(self) -> int: ...
    def __init__(self) -> None: ...
    def __repr__(self) -> str: ...
    def clean(self) -> None: ...
    def getBarStyle(self) -> str: ...
    def getDirection(self) -> str: ...
    def getLocation(self) -> str: ...
    def setBarStyle(self, barStyle: str) -> None: ...
    def setDirection(self, direction: str) -> None: ...
    def setLocation(self, location: str) -> None: ...
    def setRepeatEnd(self) -> None: ...
    def setRepeatStart(self) -> None: ...
    def toXML(self, identSize: int = 2) -> str: ...
    pass
class Chord():
    def __add__(self, arg0: Chord) -> Chord: ...
    def __eq__(self, arg0: Chord) -> bool: ...
    def __getitem__(self, arg0: int) -> Note: ...
    def __hash__(self) -> int: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, notes: typing.List[Note]) -> None: ...
    @typing.overload
    def __init__(self, pitches: typing.List[str]) -> None: ...
    def __ne__(self, arg0: Chord) -> bool: ...
    def __repr__(self) -> str: ...
    def __setitem__(self, arg0: int) -> Note: ...
    @typing.overload
    def addNote(self, note: Note) -> None: ...
    @typing.overload
    def addNote(self, pitch: str) -> None: ...
    def clear(self) -> None: ...
    def getBassNote(self) -> Note: ...
    def getCloseChord(self, enharmonyNotes: bool = False) -> Chord: ...
    def getCloseStackChord(self, enharmonyNotes: bool = False) -> Chord: ...
    def getCloseStackHarmonicComplexity(self, useEnharmony: bool = False) -> float: ...
    def getCloseStackIntervals(self, firstNoteAsReference: bool = False) -> typing.List[Interval]: ...
    def getDegree(self, key: Key, enharmonyNotes: bool = False) -> int: ...
    def getDuration(self) -> str: ...
    def getDurationTicks(self) -> int: ...
    def getFrequencyStd(self) -> float: ...
    @typing.overload
    def getHarmonicDensity(self, lowerBoundMIDI: int = -1, higherBoundMIDI: int = -1) -> float: ...
    @typing.overload
    def getHarmonicDensity(self, lowerBoundPitch: str = '', higherBoundPitch: str = '') -> float: ...
    def getHarmonicSpectrum(self, numPartials: int = 6, amplCallback: typing.Callable[[typing.List[float]], typing.List[float]] = None) -> typing.Tuple[typing.List[float], typing.List[float]]: ...
    def getIntervals(self, firstNoteAsReference: bool = False) -> typing.List[Interval]: ...
    def getIntervalsFromOriginalSortedNotes(self) -> typing.List[Interval]: ...
    def getMIDIIntervals(self, firstNoteAsReference: bool = False) -> typing.List[int]: ...
    def getMeanFrequency(self) -> float: ...
    def getMeanMidiValue(self) -> int: ...
    def getMeanOfExtremesFrequency(self) -> float: ...
    def getMeanOfExtremesMidiValue(self) -> int: ...
    def getMeanOfExtremesPitch(self, accType: str = '') -> str: ...
    def getMeanPitch(self, accType: str = '') -> str: ...
    def getMidiValueStd(self) -> float: ...
    def getName(self) -> str: ...
    def getNote(self, noteIndex: int) -> Note: ...
    def getNotes(self) -> typing.List[Note]: ...
    def getOpenStackChord(self, enharmonyNotes: bool = False) -> Chord: ...
    def getOpenStackIntervals(self, firstNoteAsReference: bool = False) -> typing.List[Interval]: ...
    def getOpenStackNotes(self) -> typing.List[Note]: ...
    def getQuarterDuration(self) -> float: ...
    def getRomanDegree(self, key: Key, enharmonyNotes: bool = False) -> str: ...
    def getRoot(self) -> Note: ...
    def getSetharesDissonanceValue(self, numPartials: int = 6, useMinModel: bool = True, amplCallback: typing.Callable[[typing.List[float]], typing.List[float]] = None) -> float: ...
    def getStackDataFrame(self, enharmonyNotes: bool = False) -> object: ...
    def haveAnyOctaveAugmentedFifth(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveAugmentedFourth(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveAugmentedOctave(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveDiminhavehedFifth(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveDiminhavehedOctave(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveDiminhavehedSeventh(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveFifth(self) -> bool: ...
    def haveAnyOctaveFourth(self) -> bool: ...
    def haveAnyOctaveMajorSecond(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveMajorSeventh(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveMajorSixth(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveMajorThird(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveMinorSecond(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveMinorSeventh(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveMinorSixth(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveMinorThird(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveOctave(self) -> bool: ...
    def haveAnyOctavePerfectFifth(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctavePerfectFourth(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctavePerfectOctave(self, useEnharmony: bool = False) -> bool: ...
    def haveAnyOctaveSecond(self) -> bool: ...
    def haveAnyOctaveSeventh(self) -> bool: ...
    def haveAnyOctaveSixth(self) -> bool: ...
    def haveAnyOctaveThird(self) -> bool: ...
    def haveAugmentedFifth(self, useEnharmony: bool = False) -> bool: ...
    def haveAugmentedFourth(self, useEnharmony: bool = False) -> bool: ...
    def haveAugmentedInterval(self, useEnharmony: bool = False) -> bool: ...
    def haveAugmentedOctave(self, useEnharmony: bool = False) -> bool: ...
    def haveAugmentedUnisson(self, useEnharmony: bool = False) -> bool: ...
    def haveDiminishedFifth(self, useEnharmony: bool = False) -> bool: ...
    def haveDiminishedInterval(self, useEnharmony: bool = False) -> bool: ...
    def haveDiminishedOctave(self, useEnharmony: bool = False) -> bool: ...
    def haveDiminishedSeventh(self, useEnharmony: bool = False) -> bool: ...
    def haveDiminishedUnisson(self, useEnharmony: bool = False) -> bool: ...
    def haveEleventh(self, useEnharmony: bool = False) -> bool: ...
    def haveFifth(self, useEnharmony: bool = False) -> bool: ...
    def haveFourth(self, useEnharmony: bool = False) -> bool: ...
    def haveMajorInterval(self, useEnharmony: bool = False) -> bool: ...
    def haveMajorNinth(self, useEnharmony: bool = False) -> bool: ...
    def haveMajorSecond(self, useEnharmony: bool = False) -> bool: ...
    def haveMajorSeventh(self, useEnharmony: bool = False) -> bool: ...
    def haveMajorSixth(self, useEnharmony: bool = False) -> bool: ...
    def haveMajorThird(self, useEnharmony: bool = False) -> bool: ...
    def haveMajorThirdteenth(self, useEnharmony: bool = False) -> bool: ...
    def haveMinorInterval(self, useEnharmony: bool = False) -> bool: ...
    def haveMinorNinth(self, useEnharmony: bool = False) -> bool: ...
    def haveMinorSecond(self, useEnharmony: bool = False) -> bool: ...
    def haveMinorSeventh(self, useEnharmony: bool = False) -> bool: ...
    def haveMinorSixth(self, useEnharmony: bool = False) -> bool: ...
    def haveMinorThird(self, useEnharmony: bool = False) -> bool: ...
    def haveMinorThirdteenth(self, useEnharmony: bool = False) -> bool: ...
    def haveNinth(self, useEnharmony: bool = False) -> bool: ...
    def haveOctave(self, useEnharmony: bool = False) -> bool: ...
    def havePerfectEleventh(self, useEnharmony: bool = False) -> bool: ...
    def havePerfectFifth(self, useEnharmony: bool = False) -> bool: ...
    def havePerfectFourth(self, useEnharmony: bool = False) -> bool: ...
    def havePerfectInterval(self, useEnharmony: bool = False) -> bool: ...
    def havePerfectOctave(self, useEnharmony: bool = False) -> bool: ...
    def havePerfectUnisson(self, useEnharmony: bool = False) -> bool: ...
    def haveSecond(self, useEnharmony: bool = False) -> bool: ...
    def haveSeventh(self, useEnharmony: bool = False) -> bool: ...
    def haveSharpEleventh(self, useEnharmony: bool = False) -> bool: ...
    def haveSixth(self, useEnharmony: bool = False) -> bool: ...
    def haveThird(self, useEnharmony: bool = False) -> bool: ...
    def haveThirdteenth(self, useEnharmony: bool = False) -> bool: ...
    def info(self) -> None: ...
    def insertNote(self, insertNote: Note, positionNote: int = 0) -> None: ...
    def inversion(self, inversionNumber: int) -> None: ...
    def isAugmentedChord(self) -> bool: ...
    def isDiminishedChord(self) -> bool: ...
    def isDominantSeventhChord(self) -> bool: ...
    def isHalfDiminishedChord(self) -> bool: ...
    def isInRootPosition(self) -> bool: ...
    def isMajorChord(self) -> bool: ...
    def isMinorChord(self) -> bool: ...
    def isSorted(self) -> bool: ...
    def isTonal(self, model: typing.Callable[[Chord], bool] = None) -> bool: ...
    def print(self) -> None: ...
    def printStack(self) -> None: ...
    def removeDuplicateNotes(self) -> None: ...
    def removeNote(self, noteIndex: int) -> None: ...
    def removeTopNote(self) -> None: ...
    def setDurationTicks(self, durationTicks: int) -> None: ...
    def size(self) -> int: ...
    def sortNotes(self) -> None: ...
    def stackSize(self) -> int: ...
    def toCents(self) -> typing.List[int]: ...
    def transpose(self, semiTonesNumber: int) -> None: ...
    def transposeStackOnly(self, semiTonesNumber: int) -> None: ...
    pass
class Clef():
    def __hash__(self) -> int: ...
    def __init__(self, sign: ClefSign = ClefSign.G, line: int = -1) -> None: ...
    def __repr__(self) -> str: ...
    def getLine(self) -> int: ...
    def getSign(self) -> ClefSign: ...
    def setLine(self, line: int) -> None: ...
    def setSign(self, sign: ClefSign) -> None: ...
    def toXML(self, clefNumber: int = -1, identSize: int = 2) -> str: ...
    pass
class ClefSign():
    """
    Members:

      G

      F

      C

      P
    """
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self, value: int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str:
        """
        :type: str
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    C: maialib.maiacore.maiacore.ClefSign # value = <ClefSign.C: 2>
    F: maialib.maiacore.maiacore.ClefSign # value = <ClefSign.F: 1>
    G: maialib.maiacore.maiacore.ClefSign # value = <ClefSign.G: 0>
    P: maialib.maiacore.maiacore.ClefSign # value = <ClefSign.P: 3>
    __members__: dict # value = {'G': <ClefSign.G: 0>, 'F': <ClefSign.F: 1>, 'C': <ClefSign.C: 2>, 'P': <ClefSign.P: 3>}
    pass
class Duration():
    """
    Members:

      MAXIMA_DOT_DOT

      MAXIMA_DOT

      MAXIMA

      LONG_DOT_DOT

      LONG_DOT

      LONG

      BREVE_DOT_DOT

      BREVE_DOT

      BREVE

      WHOLE_DOT_DOT

      WHOLE_DOT

      WHOLE

      HALF_DOT_DOT

      HALF_DOT

      HALF

      QUARTER_DOT_DOT

      QUARTER_DOT

      QUARTER

      EIGHTH_DOT_DOT

      EIGHTH_DOT

      EIGHTH

      N16TH_DOT_DOT

      N16TH_DOT

      N16TH

      N32ND_DOT_DOT

      N32ND_DOT

      N32ND

      N64TH_DOT_DOT

      N64TH_DOT

      N64TH

      N128TH_DOT_DOT

      N128TH_DOT

      N128TH

      N256TH_DOT_DOT

      N256TH_DOT

      N256TH

      N512TH_DOT_DOT

      N512TH_DOT

      N512TH

      N1024TH_DOT_DOT

      N1024TH_DOT

      N1024TH
    """
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self, value: int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str:
        """
        :type: str
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    BREVE: maialib.maiacore.maiacore.Duration # value = <Duration.BREVE: 34>
    BREVE_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.BREVE_DOT: 35>
    BREVE_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.BREVE_DOT_DOT: 36>
    EIGHTH: maialib.maiacore.maiacore.Duration # value = <Duration.EIGHTH: 22>
    EIGHTH_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.EIGHTH_DOT: 23>
    EIGHTH_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.EIGHTH_DOT_DOT: 24>
    HALF: maialib.maiacore.maiacore.Duration # value = <Duration.HALF: 28>
    HALF_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.HALF_DOT: 29>
    HALF_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.HALF_DOT_DOT: 30>
    LONG: maialib.maiacore.maiacore.Duration # value = <Duration.LONG: 37>
    LONG_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.LONG_DOT: 38>
    LONG_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.LONG_DOT_DOT: 39>
    MAXIMA: maialib.maiacore.maiacore.Duration # value = <Duration.MAXIMA: 40>
    MAXIMA_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.MAXIMA_DOT: 41>
    MAXIMA_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.MAXIMA_DOT_DOT: 42>
    N1024TH: maialib.maiacore.maiacore.Duration # value = <Duration.N1024TH: 1>
    N1024TH_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N1024TH_DOT: 2>
    N1024TH_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N1024TH_DOT_DOT: 3>
    N128TH: maialib.maiacore.maiacore.Duration # value = <Duration.N128TH: 10>
    N128TH_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N128TH_DOT: 11>
    N128TH_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N128TH_DOT_DOT: 12>
    N16TH: maialib.maiacore.maiacore.Duration # value = <Duration.N16TH: 19>
    N16TH_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N16TH_DOT: 20>
    N16TH_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N16TH_DOT_DOT: 21>
    N256TH: maialib.maiacore.maiacore.Duration # value = <Duration.N256TH: 7>
    N256TH_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N256TH_DOT: 8>
    N256TH_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N256TH_DOT_DOT: 9>
    N32ND: maialib.maiacore.maiacore.Duration # value = <Duration.N32ND: 16>
    N32ND_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N32ND_DOT: 17>
    N32ND_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N32ND_DOT_DOT: 18>
    N512TH: maialib.maiacore.maiacore.Duration # value = <Duration.N512TH: 4>
    N512TH_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N512TH_DOT: 5>
    N512TH_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N512TH_DOT_DOT: 6>
    N64TH: maialib.maiacore.maiacore.Duration # value = <Duration.N64TH: 13>
    N64TH_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N64TH_DOT: 14>
    N64TH_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.N64TH_DOT_DOT: 15>
    QUARTER: maialib.maiacore.maiacore.Duration # value = <Duration.QUARTER: 25>
    QUARTER_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.QUARTER_DOT: 26>
    QUARTER_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.QUARTER_DOT_DOT: 27>
    WHOLE: maialib.maiacore.maiacore.Duration # value = <Duration.WHOLE: 31>
    WHOLE_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.WHOLE_DOT: 32>
    WHOLE_DOT_DOT: maialib.maiacore.maiacore.Duration # value = <Duration.WHOLE_DOT_DOT: 33>
    __members__: dict # value = {'MAXIMA_DOT_DOT': <Duration.MAXIMA_DOT_DOT: 42>, 'MAXIMA_DOT': <Duration.MAXIMA_DOT: 41>, 'MAXIMA': <Duration.MAXIMA: 40>, 'LONG_DOT_DOT': <Duration.LONG_DOT_DOT: 39>, 'LONG_DOT': <Duration.LONG_DOT: 38>, 'LONG': <Duration.LONG: 37>, 'BREVE_DOT_DOT': <Duration.BREVE_DOT_DOT: 36>, 'BREVE_DOT': <Duration.BREVE_DOT: 35>, 'BREVE': <Duration.BREVE: 34>, 'WHOLE_DOT_DOT': <Duration.WHOLE_DOT_DOT: 33>, 'WHOLE_DOT': <Duration.WHOLE_DOT: 32>, 'WHOLE': <Duration.WHOLE: 31>, 'HALF_DOT_DOT': <Duration.HALF_DOT_DOT: 30>, 'HALF_DOT': <Duration.HALF_DOT: 29>, 'HALF': <Duration.HALF: 28>, 'QUARTER_DOT_DOT': <Duration.QUARTER_DOT_DOT: 27>, 'QUARTER_DOT': <Duration.QUARTER_DOT: 26>, 'QUARTER': <Duration.QUARTER: 25>, 'EIGHTH_DOT_DOT': <Duration.EIGHTH_DOT_DOT: 24>, 'EIGHTH_DOT': <Duration.EIGHTH_DOT: 23>, 'EIGHTH': <Duration.EIGHTH: 22>, 'N16TH_DOT_DOT': <Duration.N16TH_DOT_DOT: 21>, 'N16TH_DOT': <Duration.N16TH_DOT: 20>, 'N16TH': <Duration.N16TH: 19>, 'N32ND_DOT_DOT': <Duration.N32ND_DOT_DOT: 18>, 'N32ND_DOT': <Duration.N32ND_DOT: 17>, 'N32ND': <Duration.N32ND: 16>, 'N64TH_DOT_DOT': <Duration.N64TH_DOT_DOT: 15>, 'N64TH_DOT': <Duration.N64TH_DOT: 14>, 'N64TH': <Duration.N64TH: 13>, 'N128TH_DOT_DOT': <Duration.N128TH_DOT_DOT: 12>, 'N128TH_DOT': <Duration.N128TH_DOT: 11>, 'N128TH': <Duration.N128TH: 10>, 'N256TH_DOT_DOT': <Duration.N256TH_DOT_DOT: 9>, 'N256TH_DOT': <Duration.N256TH_DOT: 8>, 'N256TH': <Duration.N256TH: 7>, 'N512TH_DOT_DOT': <Duration.N512TH_DOT_DOT: 6>, 'N512TH_DOT': <Duration.N512TH_DOT: 5>, 'N512TH': <Duration.N512TH: 4>, 'N1024TH_DOT_DOT': <Duration.N1024TH_DOT_DOT: 3>, 'N1024TH_DOT': <Duration.N1024TH_DOT: 2>, 'N1024TH': <Duration.N1024TH: 1>}
    pass
class HeapData():
    pass
class Helper():
    @staticmethod
    def duration2Ticks(duration: Duration, divisionsPerQuarterNote: int = 265) -> int: ...
    @staticmethod
    def duration2noteType(duration: Duration) -> str: ...
    @staticmethod
    def durationRatio(duration_A: float, duration_B: float) -> float: ...
    @staticmethod
    def freq2equalTemperament(freq: float, referenceFreq: float = 440.0) -> float: ...
    @staticmethod
    def freq2midiNote(freq: float, modelo: typing.Callable[[float], int] = None) -> typing.Tuple[int, int]: ...
    @staticmethod
    def freq2pitch(freq: float, accType: str = '#') -> typing.Tuple[str, int]: ...
    @staticmethod
    def frequencies2cents(freq_A: float, freq_B: float) -> int: ...
    @staticmethod
    def getPercentiles(arg0: object, arg1: typing.List[float]) -> object: ...
    @staticmethod
    def isEnharmonic(arg0: str, arg1: str) -> bool: ...
    @staticmethod
    def midiNote2freq(midiNoteValue: int, freqA4: float = 440.0) -> float: ...
    @staticmethod
    def midiNote2octave(midiNote: int) -> int: ...
    @staticmethod
    def midiNote2pitch(midiNote: int, accType: str = '') -> str: ...
    @staticmethod
    def midiNote2pitches(midiNote: int) -> typing.List[str]: ...
    @staticmethod
    def noteSimilarity(pitchClass_A: str, octave_A: int, duration_A: float, pitchClass_B: str, octave_B: int, duration_B: float, enableEnharmonic: bool = False) -> typing.Tuple[float, float, float]: ...
    @staticmethod
    def noteType2duration(noteType: str) -> Duration: ...
    @staticmethod
    def noteType2ticks(noteType: str, divisionsPerQuarterNote: int = 256) -> int: ...
    @staticmethod
    def notes2Intervals(notes: typing.List[Note], firstNoteAsReference: bool = False) -> typing.List[Interval]: ...
    @staticmethod
    def number2pitch(number: float, accType: str = '#') -> str: ...
    @staticmethod
    def pitch2freq(pitch: str) -> float: ...
    @staticmethod
    def pitch2midiNote(pitch: str) -> int: ...
    @staticmethod
    def pitch2number(pitch: str) -> float: ...
    @staticmethod
    def pitchRatio(pitch_A: str, pitch_B: str) -> float: ...
    @staticmethod
    def ticks2noteType(ticks: int, divisionsPerQuarterNote: int = 256) -> typing.Tuple[str, int]: ...
    @staticmethod
    def transposePitch(pitch: str, semitones: int, accType: str = '#') -> str: ...
    pass
class Interval():
    def __hash__(self) -> int: ...
    @typing.overload
    def __init__(self, pitch_A: str = 'C4', pitch_B: str = 'C4') -> None: ...
    @typing.overload
    def __init__(self, note_A: Note, note_B: Note) -> None: ...
    def __lt__(self, arg0: Interval) -> bool: ...
    def __repr__(self) -> str: ...
    def getDiatonicInterval(self, useSingleOctave: bool = True, absoluteValue: bool = False) -> int: ...
    def getDiatonicSteps(self, useSingleOctave: bool = True, absoluteValue: bool = False) -> int: ...
    def getName(self) -> str: ...
    def getNotes(self) -> typing.List[Note]: ...
    def getNumOctaves(self, absoluteValue: bool = False) -> int: ...
    def getNumSemitones(self, absoluteValue: bool = False) -> int: ...
    def getPitchStepInterval(self) -> int: ...
    def isAnyOctaveAugmentedFifth(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveAugmentedFourth(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveAugmentedOctave(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveDiminishedFifth(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveDiminishedOctave(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveDiminishedSeventh(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveFifth(self) -> bool: ...
    def isAnyOctaveFourth(self) -> bool: ...
    def isAnyOctaveMajorSecond(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveMajorSeventh(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveMajorSixth(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveMajorThird(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveMinorSecond(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveMinorSeventh(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveMinorSixth(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveMinorThird(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveOctave(self) -> bool: ...
    def isAnyOctavePerfectFifth(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctavePerfectFourth(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctavePerfectOctave(self, useEnharmony: bool = False) -> bool: ...
    def isAnyOctaveSecond(self) -> bool: ...
    def isAnyOctaveSeventh(self) -> bool: ...
    def isAnyOctaveSixth(self) -> bool: ...
    def isAnyOctaveThird(self) -> bool: ...
    def isAscendant(self) -> bool: ...
    def isAugmented(self, useEnharmony: bool = False) -> bool: ...
    def isAugmentedFifth(self, useEnharmony: bool = False) -> bool: ...
    def isAugmentedFourth(self, useEnharmony: bool = False) -> bool: ...
    def isAugmentedOctave(self, useEnharmony: bool = False) -> bool: ...
    def isAugmentedUnisson(self, useEnharmony: bool = False) -> bool: ...
    def isCompound(self) -> bool: ...
    def isDescendant(self) -> bool: ...
    def isDiminished(self, useEnharmony: bool = False) -> bool: ...
    def isDiminishedFifth(self, useEnharmony: bool = False) -> bool: ...
    def isDiminishedOctave(self, useEnharmony: bool = False) -> bool: ...
    def isDiminishedSeventh(self, useEnharmony: bool = False) -> bool: ...
    def isDiminishedUnisson(self, useEnharmony: bool = False) -> bool: ...
    def isEleventh(self, useEnharmony: bool = False) -> bool: ...
    def isFifth(self, useEnharmony: bool = False) -> bool: ...
    def isFourth(self, useEnharmony: bool = False) -> bool: ...
    def isMajor(self, useEnharmony: bool = False) -> bool: ...
    def isMajorNinth(self, useEnharmony: bool = False) -> bool: ...
    def isMajorSecond(self, useEnharmony: bool = False) -> bool: ...
    def isMajorSeventh(self, useEnharmony: bool = False) -> bool: ...
    def isMajorSixth(self, useEnharmony: bool = False) -> bool: ...
    def isMajorThird(self, useEnharmony: bool = False) -> bool: ...
    def isMajorThirdteenth(self, useEnharmony: bool = False) -> bool: ...
    def isMinor(self, useEnharmony: bool = False) -> bool: ...
    def isMinorNinth(self, useEnharmony: bool = False) -> bool: ...
    def isMinorSecond(self, useEnharmony: bool = False) -> bool: ...
    def isMinorSeventh(self, useEnharmony: bool = False) -> bool: ...
    def isMinorSixth(self, useEnharmony: bool = False) -> bool: ...
    def isMinorThird(self, useEnharmony: bool = False) -> bool: ...
    def isMinorThirdteenth(self, useEnharmony: bool = False) -> bool: ...
    def isNinth(self, useEnharmony: bool = False) -> bool: ...
    def isOctave(self, useEnharmony: bool = False) -> bool: ...
    def isPerfect(self, useEnharmony: bool = False) -> bool: ...
    def isPerfectEleventh(self, useEnharmony: bool = False) -> bool: ...
    def isPerfectFifth(self, useEnharmony: bool = False) -> bool: ...
    def isPerfectFourth(self, useEnharmony: bool = False) -> bool: ...
    def isPerfectOctave(self, useEnharmony: bool = False) -> bool: ...
    def isPerfectUnisson(self, useEnharmony: bool = False) -> bool: ...
    def isSecond(self, useEnharmony: bool = False) -> bool: ...
    def isSeventh(self, useEnharmony: bool = False) -> bool: ...
    def isSharpEleventh(self, useEnharmony: bool = False) -> bool: ...
    def isSimple(self) -> bool: ...
    def isSixth(self, useEnharmony: bool = False) -> bool: ...
    def isThird(self, useEnharmony: bool = False) -> bool: ...
    def isThirdteenth(self, useEnharmony: bool = False) -> bool: ...
    def isTonal(self) -> bool: ...
    @typing.overload
    def setNotes(self, pitch_A: str, pitch_B: str) -> None: ...
    @typing.overload
    def setNotes(self, note_A: Note, note_B: Note) -> None: ...
    def toCents(self) -> int: ...
    pass
class Key():
    def __hash__(self) -> int: ...
    @typing.overload
    def __init__(self, fifthCircle: int = 0, isMajorMode: bool = True) -> None: ...
    @typing.overload
    def __init__(self, key: str) -> None: ...
    def __repr__(self) -> str: ...
    def getFifthCircle(self) -> int: ...
    def getName(self) -> str: ...
    def getRelativeKeyName(self) -> str: ...
    def isMajorMode(self) -> int: ...
    def setFifthCircle(self, fifthCircle: int) -> None: ...
    def setIsMajorMode(self, isMajorMode: bool) -> None: ...
    pass
class Measure():
    def __hash__(self) -> int: ...
    def __init__(self, numStaves: int = 1, divisionsPerQuarterNote: int = 256) -> None: ...
    def __repr__(self) -> str: ...
    @typing.overload
    def addNote(self, note: Note, staveId: int = 0, position: int = -1) -> None: 
        """
        Add a single Note object

        Add a Note object vector

        Create a new Note Obj and add it

        Create a new Note vector and add it
        """
    @typing.overload
    def addNote(self, noteVec: typing.List[Note], staveId: int = 0, position: int = -1) -> None: ...
    @typing.overload
    def addNote(self, pitchClass: str, staveId: int = 0, position: int = -1) -> None: ...
    @typing.overload
    def addNote(self, pitchClassVec: typing.List[str], staveId: int = 0, position: int = -1) -> None: ...
    def clear(self) -> None: ...
    def divisionsPerQuarterNoteChanged(self) -> bool: ...
    def getBarlineLeft(self) -> Barline: ...
    def getBarlineRight(self) -> Barline: ...
    def getClef(self, clefId: int = 0) -> Clef: ...
    def getDivisionsPerQuarterNote(self) -> int: ...
    def getDurationTicks(self) -> int: ...
    def getEmptyDurationTicks(self) -> int: ...
    def getFifthCircle(self) -> int: ...
    def getFilledDurationTicks(self, staveId: int = 0) -> int: ...
    def getFilledQuarterDuration(self, staveId: int = 0) -> float: ...
    def getFreeDurationTicks(self, staveId: int = 0) -> int: ...
    def getFreeQuarterDuration(self, staveId: int = 0) -> float: ...
    def getKey(self) -> Key: ...
    def getKeyName(self) -> str: ...
    def getKeySignature(self) -> str: ...
    def getNote(self, noteId: int, staveId: int = 0) -> Note: ...
    def getNoteOff(self, noteOffId: int, staveId: int = 0) -> Note: ...
    def getNoteOn(self, noteOnId: int, staveId: int = 0) -> Note: ...
    @typing.overload
    def getNumNotes(self) -> int: ...
    @typing.overload
    def getNumNotes(self, staveId: int) -> int: ...
    @typing.overload
    def getNumNotesOff(self) -> int: ...
    @typing.overload
    def getNumNotesOff(self, staveId: int) -> int: ...
    @typing.overload
    def getNumNotesOn(self) -> int: ...
    @typing.overload
    def getNumNotesOn(self, staveId: int) -> int: ...
    def getNumStaves(self) -> int: ...
    def getNumber(self) -> int: ...
    def getQuarterDuration(self) -> float: ...
    def getTimeMetronome(self) -> typing.Tuple[str, int]: ...
    def getTimeSignature(self) -> typing.Tuple[int, int]: ...
    def info(self) -> None: ...
    def isClefChanged(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def isMajorKeyMode(self) -> bool: ...
    def keySignatureChanged(self) -> bool: ...
    def metronomeChanged(self) -> bool: ...
    def removeNote(self, noteId: int, staveId: int = 0) -> None: ...
    def removeRepeatEnd(self) -> None: ...
    def removeRepeatStart(self) -> None: ...
    def setDivisionsPerQuarterNote(self, arg0: int) -> None: ...
    def setIsDivisionsPerQuarterNoteChanged(self, isDivisionsPerQuarterNoteChanged: bool = False) -> None: ...
    def setIsKeySignatureChanged(self, isKeySignatureChanged: bool = False) -> None: ...
    def setIsMetronomeChanged(self, isMetronomeChanged: bool = False) -> None: ...
    def setIsTimeSignatureChanged(self, isTimeSignatureChanged: bool = False) -> None: ...
    def setKey(self, fifthCircle: int, isMajorMode: bool = True) -> None: ...
    def setKeyMode(self, isMajorMode: bool) -> None: ...
    def setKeySignature(self, fifthCircle: int, isMajorMode: bool = True) -> None: ...
    def setMetronome(self, bpm: int, duration: Duration = Duration.QUARTER) -> None: ...
    def setNumStaves(self, numStaves: int) -> None: ...
    def setNumber(self, measureNumber: int) -> None: ...
    def setRepeatEnd(self) -> None: ...
    def setRepeatStart(self) -> None: ...
    def setTimeSignature(self, upper: int, lower: int) -> None: ...
    def timeSignatureChanged(self) -> bool: ...
    def toJSON(self) -> str: ...
    def toXML(self, instrumentId: int = 1, identSize: int = 2) -> str: ...
    pass
class Note():
    def __eq__(self, arg0: Note) -> bool: ...
    def __ge__(self, arg0: Note) -> bool: ...
    def __gt__(self, arg0: Note) -> bool: ...
    def __hash__(self) -> int: ...
    @typing.overload
    def __init__(self, pitch: str, duration: Duration = Duration.QUARTER, isNoteOn: bool = True, inChord: bool = False, transposeDiatonic: int = 0, transposeChromatic: int = 0, divisionsPerQuarterNote: int = 256) -> None: ...
    @typing.overload
    def __init__(self, midiNumber: int, accType: str = '', duration: Duration = Duration.QUARTER, isNoteOn: bool = True, inChord: bool = False, transposeDiatonic: int = 0, transposeChromatic: int = 0, divisionsPerQuarterNote: int = 256) -> None: ...
    def __le__(self, arg0: Note) -> bool: ...
    def __lt__(self, arg0: Note) -> bool: ...
    def __ne__(self, arg0: Note) -> bool: ...
    def __repr__(self) -> str: ...
    def addArticulation(self, articulation: str) -> None: ...
    def addBeam(self, beam: str) -> None: ...
    def addSlur(self, slurType: str, slurOrientation: str) -> None: ...
    def addTie(self, tieType: str) -> None: ...
    def getAlterSymbol(self) -> str: ...
    def getArticulation(self) -> typing.List[str]: ...
    def getBeam(self) -> typing.List[str]: ...
    def getDiatonicSoundingPitchClass(self) -> str: ...
    def getDiatonicWrittenPitchClass(self) -> str: ...
    def getDivisionsPerQuarterNote(self) -> int: ...
    def getDuration(self) -> float: ...
    def getDurationTicks(self) -> int: ...
    def getEnharmonicNote(self, alternativeEnhamonicPitch: bool = False) -> Note: ...
    def getEnharmonicNotes(self, includeCurrentPitch: bool = False) -> typing.List[Note]: ...
    def getEnharmonicPitch(self, alternativeEnhamonicPitch: bool = False) -> str: ...
    def getEnharmonicPitches(self, includeCurrentPitch: bool = False) -> typing.List[str]: ...
    def getFrequency(self, equalTemperament: bool = True, freqA4: float = 440.0) -> float: ...
    def getHarmonicSpectrum(self, numPartials: int = 6, amplCallback: typing.Callable[[typing.List[float]], typing.List[float]] = None) -> typing.Tuple[typing.List[float], typing.List[float]]: ...
    def getLongType(self) -> str: ...
    def getMIDINumber(self) -> int: ...
    def getNumDots(self) -> int: ...
    def getOctave(self) -> int: ...
    def getPitch(self) -> str: ...
    def getPitchClass(self) -> str: ...
    def getPitchStep(self) -> str: ...
    def getQuarterDuration(self) -> float: ...
    def getScaleDegree(self, key: Key) -> int: ...
    def getShortType(self) -> str: ...
    def getSlur(self) -> typing.Tuple[str, str]: ...
    def getSoundingOctave(self) -> int: ...
    def getSoundingPitch(self) -> str: ...
    def getSoundingPitchClass(self) -> str: ...
    def getStaff(self) -> int: ...
    def getStem(self) -> str: ...
    def getTie(self) -> typing.List[str]: ...
    def getTransposeChromatic(self) -> int: ...
    def getTransposeDiatonic(self) -> int: ...
    def getType(self) -> str: ...
    def getUnpitchedIndex(self) -> int: ...
    def getVoice(self) -> int: ...
    def getWrittenOctave(self) -> int: ...
    def getWrittenPitch(self) -> str: ...
    def getWrittenPitchClass(self) -> str: ...
    def inChord(self) -> bool: ...
    def info(self) -> None: ...
    def isDotted(self) -> bool: ...
    def isDoubleDotted(self) -> bool: ...
    def isGraceNote(self) -> bool: ...
    def isNoteOff(self) -> bool: ...
    def isNoteOn(self) -> bool: ...
    def isPitched(self) -> bool: ...
    def isTransposed(self) -> bool: ...
    def removeDots(self) -> None: ...
    def removeTies(self) -> None: ...
    def setDoubleDot(self) -> None: ...
    @typing.overload
    def setDuration(self, duration: Duration, divisionsPerQuarterNote: int = 256) -> None: ...
    @typing.overload
    def setDuration(self, durationValue: float, lowerTimeSignatureValue: int = 4, divisionsPerQuarterNote: int = 256) -> None: ...
    def setDurationTicks(self, durationTicks: int) -> None: ...
    def setIsGraceNote(self, isGraceNote: bool = False) -> None: ...
    def setIsInChord(self, inChord: bool) -> None: ...
    def setIsNoteOn(self, isNoteOn: bool) -> None: ...
    def setIsPitched(self, isPitched: bool = True) -> None: ...
    def setIsTuplet(self, isTuplet: bool = False) -> None: ...
    def setOctave(self, octave: int) -> None: ...
    def setPitch(self, pitch: str) -> None: ...
    def setPitchClass(self, pitchClass: str) -> None: 
        """
        Set the note pitch class
        """
    def setSingleDot(self) -> None: ...
    def setStaff(self, staff: int) -> None: ...
    def setStem(self, stem: str) -> None: ...
    def setTieStart(self) -> None: ...
    def setTieStop(self) -> None: ...
    def setTieStopStart(self) -> None: ...
    def setTransposingInterval(self, diatonicInterval: int, chromaticInterval: int) -> None: ...
    def setTupleValues(self, actualNotes: int, normalNotes: int, normalType: str = 'eighth') -> None: ...
    def setUnpitchedIndex(self, arg0: int) -> None: ...
    def setVoice(self, voice: int) -> None: ...
    def toEnharmonicPitch(self, alternativeEnhamonicPitch: bool = False) -> None: ...
    def toXML(self, instrumentId: int = 1, identSize: int = 2) -> str: ...
    def transpose(self, semitones: int, accType: str = '') -> None: ...
    pass
class NoteData():
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, note: Note, wasEnharmonized: bool, enharmonicDiatonicDistance: int) -> None: ...
    pass
class NoteDataHeap():
    pass
class Part():
    def __hash__(self) -> int: ...
    def __init__(self, partName: str, numStaves: int = 1, isPitched: bool = True, divisionsPerQuarterNote: int = 256) -> None: ...
    def __repr__(self) -> str: ...
    def addMeasure(self, numMeasures: int) -> None: ...
    def addMidiUnpitched(self, midiUnpitched: int) -> None: ...
    def addStaves(self, numStaves: int = 1) -> None: ...
    @typing.overload
    def append(self, obj: typing.Union[Note, Chord], position: int = -1, staveId: int = 0) -> None: ...
    @typing.overload
    def append(self, objs: typing.List[typing.Union[Note, Chord]], position: int = -1, staveId: int = 0) -> None: ...
    def clear(self) -> None: ...
    def getMeasure(self, measureId: int) -> Measure: ...
    def getMidiUnpitched(self) -> typing.List[int]: ...
    def getName(self) -> str: ...
    def getNumMeasures(self) -> int: ...
    def getNumNotes(self, staveId: int = -1) -> int: ...
    def getNumNotesOff(self, staveId: int = -1) -> int: ...
    def getNumNotesOn(self, staveId: int = -1) -> int: ...
    def getNumStaves(self) -> int: ...
    def getPartIndex(self) -> int: ...
    def getShortName(self) -> str: ...
    def getStaffLines(self) -> int: ...
    def info(self) -> None: ...
    def isPitched(self) -> bool: ...
    def removeMeasure(self, measureStart: int, measureEnd: int) -> None: ...
    def removeStave(self, staveId: int) -> None: ...
    def setIsPitched(self, isPitched: bool = True) -> None: ...
    def setNumStaves(self, numStaves: int) -> None: ...
    def setPartIndex(self, partIdx: int) -> None: ...
    def setShortName(self, shortName: str) -> None: ...
    def setStaffLines(self, staffLines: int = 5) -> None: ...
    def toJSON(self) -> str: ...
    def toXML(self, instrumentId: int = 1, identSize: int = 2) -> str: ...
    pass
class Score():
    def __hash__(self) -> int: ...
    @typing.overload
    def __init__(self, partsName: typing.List[str], numMeasures: int = 20) -> None: ...
    @typing.overload
    def __init__(self, filePath: str) -> None: ...
    def __repr__(self) -> str: ...
    def addMeasure(self, numMeasures: int) -> None: ...
    def addPart(self, partName: str, numStaves: int = 1) -> None: ...
    def clear(self) -> None: ...
    def forEachNote(self, callback: typing.Callable[[Part, Measure, int, Note], None], measureStart: int = 0, measureEnd: int = -1, partNames: typing.List[str] = []) -> None: ...
    def getChords(self, config: json = None) -> typing.List[typing.Tuple[int, float, Key, Chord]]: ...
    def getChordsDataFrame(self, config: json = None) -> object: ...
    def getComposerName(self) -> str: ...
    def getNumMeasures(self) -> int: ...
    def getNumNotes(self) -> int: ...
    def getNumParts(self) -> int: ...
    @typing.overload
    def getPart(self, partId: int) -> Part: ...
    @typing.overload
    def getPart(self, partName: str) -> Part: ...
    def getPartIndex(self, partName: str, index: int) -> bool: ...
    def getPartName(self, partId: int) -> str: ...
    def getPartsNames(self) -> typing.List[str]: ...
    def getTitle(self) -> str: ...
    def info(self) -> None: ...
    def instrumentFragmentation(self, config: json = None) -> json: ...
    def isValid(self) -> bool: ...
    def removeMeasure(self, measureStart: int, measureEnd: int) -> None: ...
    def removePart(self, partId: int) -> None: ...
    def selectNotes(self, config: json) -> json: ...
    def setComposerName(self, composerName: str) -> None: ...
    @typing.overload
    def setKeySignature(self, fifthCicle: int, isMajorMode: bool = True, measureId: int = 0) -> None: ...
    @typing.overload
    def setKeySignature(self, key: str, measureId: int = 0) -> None: ...
    def setMetronomeMark(self, bpm: int, duration: Duration = Duration.QUARTER, measureStart: int = 0) -> None: ...
    def setRepeat(self, measureStart: int, measureEnd: int = -1) -> None: ...
    def setTimeSignature(self, timeUpper: int, timeLower: int, measureId: int = -1) -> None: ...
    def setTitle(self, scoreTitle: str) -> None: ...
    def toDataFrame(self) -> object: ...
    def toFile(self, fileName: str, compressedXML: bool = False, identSize: int = 2) -> None: ...
    def toJSON(self) -> str: ...
    def toXML(self, identSize: int = 2) -> str: ...
    def xPathCountNodes(self, xPath: str) -> int: ...
    pass
class ScoreCollection():
    def __add__(self, arg0: ScoreCollection) -> ScoreCollection: ...
    def __hash__(self) -> int: ...
    @typing.overload
    def __init__(self, collectionName: str, directoryPath: str = '') -> None: ...
    @typing.overload
    def __init__(self, collectionName: str, directoriesPaths: typing.List[str] = []) -> None: ...
    def __repr__(self) -> str: ...
    def addDirectory(self, directoryPath: str) -> None: ...
    @typing.overload
    def addScore(self, score: Score) -> None: ...
    @typing.overload
    def addScore(self, filePath: str) -> None: ...
    @typing.overload
    def addScore(self, filePaths: typing.List[str]) -> None: ...
    def clear(self) -> None: ...
    def getDirectoriesPaths(self) -> typing.List[str]: ...
    def getName(self) -> str: ...
    def getNumDirectories(self) -> int: ...
    def getNumScores(self) -> int: ...
    def getScores(self) -> typing.List[Score]: ...
    def isEmpty(self) -> bool: ...
    def merge(self, other: ScoreCollection, mergedCollectionName: str = '') -> None: ...
    def removeScore(self, scoreIdx: int) -> None: ...
    def setDirectoriesPaths(self, directoriesPaths: typing.List[str]) -> None: ...
    def setName(self, collectionName: str) -> None: ...
    pass
__version__ = '1.4.0'
